# Breaking Application Quality Seals when Initiatives Reach End of Life
### On this page
  * [Overview](https://help.sap.com/docs/leanix/ea/breaking-application-quality-seals-when-initiatives-reach-end-of-life#overview)
  * [Prerequisites](https://help.sap.com/docs/leanix/ea/breaking-application-quality-seals-when-initiatives-reach-end-of-life#prerequisites)
  * [Automation Logic](https://help.sap.com/docs/leanix/ea/breaking-application-quality-seals-when-initiatives-reach-end-of-life#automation-logic)
  * [How It Works: Example](https://help.sap.com/docs/leanix/ea/breaking-application-quality-seals-when-initiatives-reach-end-of-life#how-it-works:-example)
  * [Technical Details](https://help.sap.com/docs/leanix/ea/breaking-application-quality-seals-when-initiatives-reach-end-of-life#technical-details)
  * [Configuration](https://help.sap.com/docs/leanix/ea/breaking-application-quality-seals-when-initiatives-reach-end-of-life#configuration)
  * [Automation 1: Lifecycle Phase Is Reached](https://help.sap.com/docs/leanix/ea/breaking-application-quality-seals-when-initiatives-reach-end-of-life#automation-1:-lifecycle-phase-is-reached)
  * [Automation 2: Relation Is Added](https://help.sap.com/docs/leanix/ea/breaking-application-quality-seals-when-initiatives-reach-end-of-life#automation-2:-relation-is-added)
  * [Validation](https://help.sap.com/docs/leanix/ea/breaking-application-quality-seals-when-initiatives-reach-end-of-life#validation)


Configure automations with scripts to automatically break quality seals on applications when related initiatives reach End of Life.
